@@ -4,7 +4,7 @@ use warnings;
 
 package Dancer::Plugin::Queue::Role::Queue;
 # ABSTRACT: Dancer::Plugin::Queue implementation API
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Moo::Role;
 
@@ -17,39 +17,58 @@ requires 'remove_msg';
 1;
 
 
-# vim: ts=2 sts=2 sw=2 et:
+# vim: ts=4 sts=4 sw=4 et:
 
 __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Dancer::Plugin::Queue::Role::Queue - Dancer::Plugin::Queue implementation API
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
-  use Dancer::Plugin::Queue::Role::Queue;
+    package Dancer::Plugin::Queue::MyBackend
+
+    use Moo;
+    with 'Dancer::Plugin::Queue::Role::Queue';
+
+    sub add_msg    { ... }
+
+    sub get_msg    { ... }
+
+    sub remove_msg { ... }
 
 =head1 DESCRIPTION
 
-This module might be cool, but you'd never know it from the lack
-of documentation.
+This role specifies the API required by queue backend implementations.
+The following methods must be provided:
+
+=over 4
+
+=item *
+
+add_msg
+
+=item *
+
+get_msg
+
+=item *
+
+remove_msg
+
+=back
 
 =for Pod::Coverage method_names_here
 
-=head1 USAGE
-
-Good luck!
-
-=head1 SEE ALSO
-
-Maybe other modules do related things.
-
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
